@@ -13,10 +13,23 @@ class FileExtender(DefaultExtender):
     adapts(ATFile)
 
     fields = DefaultExtender.fields + [
+        fields.StringField(
+            name='title',
+            required=False,
+            searchable=True,
+            default='',
+            accessor='Title',
+            widget=widgets.StringWidget(
+                label_msgid='label_title',
+                visible={'view' : 'invisible'},
+                i18n_domain='plone',
+            ),
+        ),
         fields.FileField('file',
             required=True,
+            primary=True,
             searchable=True,
-            languageIndependent=True,
+            languageIndependent=False,
             storage = AnnotationStorage(migrate=True),
             widget = widgets.FileWidget(
                 description = '',
